# pyCRT

Tools for measuring the Polarized Capillary Refill Time (alternatively known
as Reflective CRT) using Python.

Documentation and a basic tutorial are available on [Read the
Docs](https://pyCRT.readthedocs.io/en/latest/index.html).
